/hg/release/icedtea6-1.8: 2 new changesets

doko at icedtea.classpath.org doko at icedtea.classpath.org
Sat Apr 10 13:33:54 PDT 2010


changeset 851c305dcf0d in /hg/release/icedtea6-1.8
details: http://icedtea.classpath.org/hg/release/icedtea6-1.8?cmd=changeset;node=851c305dcf0d
author: doko at ubuntu.com
date: Sat Apr 10 22:05:32 2010 +0200

	Always apply the NSS patch, always install nss.cfg, depending on the
	--enable-nss option comment/uncomment the security provider in
	java.security.

	2010-04-10 Matthias Klose <doko at ubuntu.com>

	 * Makefile.am (ICEDTEA_PATCHES): Always apply
	icedtea-nss-6763530.patch. Apply icedtea-nss-not-enabled-
	config.patch if the NSS-based security provider is disabled
	by default.
		* configure.ac: Be verbose wether the NSS-based security provider
	is enabled or disabled by default.
		* patches/icedtea-nss-not-enabled-config.patch: New.

	2010-04-08 Andrew John Hughes <ahughes at redhat.com>

	 * configure.ac: Move NSS detection to macros in
	acinclude.m4.
		* acinclude.m4: (IT_OBTAIN_DEFAULT_LIBDIR): Attempts to
	discover the system library directory (e.g /usr/lib64)
	(IT_LOCATE_NSS): Always try and detect NSS and only resort
	to using the system library directory detection if NSS is
	not detected.

	2010-04-08 Matthias Klose <doko at ubuntu.com>

	 * Makefile.am (stamps/icedtea.stamp, stamps/icedtea-
	debug.stamp): Always install nss.cfg.
		* configure.ac: Always make nss.cfg a config file, always
	substitute NSS_LIBDIR.


changeset 08661c42a3ba in /hg/release/icedtea6-1.8
details: http://icedtea.classpath.org/hg/release/icedtea6-1.8?cmd=changeset;node=08661c42a3ba
author: doko at ubuntu.com
date: Sat Apr 10 22:07:13 2010 +0200

	- Merge branch


diffstat:

16 files changed, 395 insertions(+), 295 deletions(-)
ChangeLog                                                    |   27 +
Makefile.am                                                  |   12 
acinclude.m4                                                 |   40 ++
configure.ac                                                 |   22 -
patches/icedtea-nss-not-enabled-config.patch                 |   13 
patches/zero/6939845.patch                                   |   20 +
patches/zero/cppInterpreter-fast-bytecodes.patch             |   15 
plugin/icedteanp/IcedTeaJavaRequestProcessor.cc              |   97 ++--
plugin/icedteanp/IcedTeaNPPlugin.cc                          |  200 +++++-----
plugin/icedteanp/IcedTeaNPPlugin.h                           |    4 
plugin/icedteanp/IcedTeaPluginRequestProcessor.cc            |  135 +++---
plugin/icedteanp/IcedTeaPluginRequestProcessor.h             |   16 
plugin/icedteanp/IcedTeaPluginUtils.cc                       |   61 ++-
plugin/icedteanp/IcedTeaPluginUtils.h                        |   19 
plugin/icedteanp/IcedTeaScriptablePluginObject.cc            |    7 
plugin/icedteanp/java/sun/applet/PluginProxyInfoRequest.java |    2 

diffs (truncated from 1688 to 500 lines):

diff -r 5a890a745e14 -r 08661c42a3ba ChangeLog
--- a/ChangeLog	Thu Apr 08 17:00:19 2010 +0200
+++ b/ChangeLog	Sat Apr 10 22:07:13 2010 +0200
@@ -1,3 +1,30 @@ 2010-04-07  Xerxes RÃ¥nby  <xerxes at zafen
+2010-04-10  Matthias Klose  <doko at ubuntu.com>
+
+	* Makefile.am (ICEDTEA_PATCHES): Always apply
+	icedtea-nss-6763530.patch. Apply icedtea-nss-not-enabled-config.patch
+	if the NSS-based security provider is disabled by default.
+	* configure.ac: Be verbose wether the NSS-based security provider
+	is enabled or disabled by default.
+	* patches/icedtea-nss-not-enabled-config.patch: New.
+
+2010-04-08  Andrew John Hughes  <ahughes at redhat.com>
+
+	* configure.ac: Move NSS detection to macros
+	in acinclude.m4.
+	* acinclude.m4:
+	(IT_OBTAIN_DEFAULT_LIBDIR): Attempts to discover the
+	system library directory (e.g /usr/lib64)
+	(IT_LOCATE_NSS): Always try and detect NSS
+	and only resort to using the system library directory
+	detection if NSS is not detected.
+
+2010-04-08  Matthias Klose  <doko at ubuntu.com>
+
+	* Makefile.am (stamps/icedtea.stamp, stamps/icedtea-debug.stamp):
+	Always install nss.cfg.
+	* configure.ac: Always make nss.cfg a config file, always
+	substitute NSS_LIBDIR.
+
 2010-04-07  Xerxes RÃ¥nby  <xerxes at zafena.se>
 
 	* configure.ac: Updated check for shared LLVM library to include svn.
diff -r 5a890a745e14 -r 08661c42a3ba Makefile.am
--- a/Makefile.am	Thu Apr 08 17:00:19 2010 +0200
+++ b/Makefile.am	Sat Apr 10 22:07:13 2010 +0200
@@ -220,7 +220,7 @@ ICEDTEA_PATCHES = \
 	patches/zero/6909153.patch \
 	patches/zero/6913869.patch \
 	patches/zero/6914622.patch \
-	patches/zero/cppInterpreter-fast-bytecodes.patch \
+	patches/zero/6939845.patch \
 	patches/icedtea-notice-safepoints.patch \
 	patches/icedtea-parisc-opt.patch \
 	patches/icedtea-lucene-crash.patch \
@@ -373,9 +373,11 @@ ICEDTEA_PATCHES += patches/icedtea-syste
 ICEDTEA_PATCHES += patches/icedtea-systemtap.patch
 endif
 
+ICEDTEA_PATCHES += patches/icedtea-nss-6763530.patch
 if ENABLE_NSS
-ICEDTEA_PATCHES += patches/icedtea-nss-config.patch \
-		   patches/icedtea-nss-6763530.patch
+ICEDTEA_PATCHES += patches/icedtea-nss-config.patch
+else
+ICEDTEA_PATCHES += patches/icedtea-nss-not-enabled-config.patch
 endif
 
 if WITH_ALT_HSBUILD
@@ -1334,10 +1336,8 @@ if ENABLE_SYSTEMTAP
 	cp $(abs_top_builddir)/tapset/jstack.stp \
 	  $(BUILD_OUTPUT_DIR)/j2sdk-image/tapset/jstack.stp
 endif
-if ENABLE_NSS
 	cp $(abs_top_builddir)/nss.cfg \
 	  $(BUILD_OUTPUT_DIR)/j2sdk-image/jre/lib/security;
-endif
 if WITH_TZDATA_DIR
 	cp $(abs_top_builddir)/tz.properties \
 	  $(BUILD_OUTPUT_DIR)/j2sdk-image/jre/lib;
@@ -1426,10 +1426,8 @@ if ENABLE_SYSTEMTAP
 	cp $(abs_top_builddir)/tapset/jstack.stp \
 	  $(BUILD_OUTPUT_DIR)-debug/j2sdk-image/tapset/jstack.stp
 endif
-if ENABLE_NSS
 	cp $(abs_top_builddir)/nss.cfg \
 	  $(BUILD_OUTPUT_DIR)-debug/j2sdk-image/jre/lib/security;
-endif
 if WITH_TZDATA_DIR
 	cp $(abs_top_builddir)/tz.properties \
 	  $(BUILD_OUTPUT_DIR)-debug/j2sdk-image/jre/lib;
diff -r 5a890a745e14 -r 08661c42a3ba acinclude.m4
--- a/acinclude.m4	Thu Apr 08 17:00:19 2010 +0200
+++ b/acinclude.m4	Sat Apr 10 22:07:13 2010 +0200
@@ -1532,3 +1532,43 @@ fi
 fi
 ])
 
+AC_DEFUN_ONCE([IT_OBTAIN_DEFAULT_LIBDIR],
+[
+dnl find the system library directory
+AC_CACHE_CHECK([for system library directory], [it_cv_default_libdir],
+[
+if test "x$LDD" = x; then
+  it_cv_default_libdir=/usr/lib
+else
+  AC_LANG_CONFTEST([AC_LANG_PROGRAM([[]], [[]])])
+  $CC conftest.c
+  syslibdir=`$LDD a.out | sed -n '/libc\.so./s,.*=> */\(@<:@^/@:>@*\)/.*,\1,p'`
+  rm -f a.out
+  case x${syslibdir} in
+    xlib|xlib64|xlib32|xlibn32) NSS_LIBDIR=/usr/${syslibdir};;
+    *) it_cv_default_libdir=/usr/lib
+  esac
+fi
+])
+AC_SUBST([DEFAULT_LIBDIR], $it_cv_default_libdir)
+])
+
+AC_DEFUN_ONCE([IT_LOCATE_NSS],
+[
+AC_REQUIRE([IT_OBTAIN_DEFAULT_LIBDIR])
+PKG_CHECK_MODULES(NSS, nss, [NSS_FOUND=yes], [NSS_FOUND=no])
+if test "x${NSS_FOUND}" = xno
+then
+  if test "x${ENABLE_NSS}" = "xyes"
+  then
+    AC_MSG_ERROR([Could not find NSS.  Either install it or configure using --disable-nss.])
+  else
+    AC_MSG_WARN([Could not find NSS; using $DEFAULT_LIBDIR as its location.])
+    NSS_LIBDIR=$DEFAULT_LIBDIR
+  fi
+else
+  NSS_LIBDIR=`$PKG_CONFIG --variable=libdir nss`
+fi
+AC_SUBST(NSS_LIBDIR)
+AC_CONFIG_FILES([nss.cfg])
+])
diff -r 5a890a745e14 -r 08661c42a3ba configure.ac
--- a/configure.ac	Thu Apr 08 17:00:19 2010 +0200
+++ b/configure.ac	Sat Apr 10 22:07:13 2010 +0200
@@ -37,6 +37,7 @@ if test "x$FASTJAR" = x; then
 	AC_MSG_ERROR([Can't find fastjar or jar])
 fi
 AC_SUBST([FASTJAR])
+AC_CHECK_TOOL([LDD], [ldd])
 dnl OpenJDK's README-builds.html lists gawk as a build dependency so we
 dnl check for it explicitly rather than using AC_PROG_AWK.
 FIND_TOOL([GAWK], [gawk])
@@ -143,13 +144,20 @@ AM_CONDITIONAL([ENABLE_SYSTEMTAP], [test
 AM_CONDITIONAL([ENABLE_SYSTEMTAP], [test x$ENABLE_SYSTEMTAP = xyes])
 AC_MSG_RESULT(${ENABLE_SYSTEMTAP})
 
+IT_LOCATE_NSS
+
 AC_MSG_CHECKING([whether to include the NSS-based security provider])
 AC_ARG_ENABLE([nss],
 	      [AS_HELP_STRING([--enable-nss],
 	      		      [Enable inclusion of NSS security provider])],
 	      [ENABLE_NSS="${enableval}"], [ENABLE_NSS='no'])
 AM_CONDITIONAL([ENABLE_NSS], [test x$ENABLE_NSS = xyes])
-AC_MSG_RESULT(${ENABLE_NSS})
+if test "x${ENABLE_NSS}" = "xyes"
+then
+  AC_MSG_RESULT([yes])
+else
+  AC_MSG_RESULT([yes, disabled by default (edit java.security to enable)])
+fi
 
 IT_GET_PKGVERSION
 IT_GET_LSB_DATA
@@ -407,18 +415,6 @@ then
   AC_SUBST(LIBPULSE_LIBS)
 fi
 
-if test "x${ENABLE_NSS}" = "xyes"
-then
-  PKG_CHECK_MODULES(NSS, nss, [NSS_FOUND=yes], [NSS_FOUND=no])
-  if test "x${NSS_FOUND}" = xno
-  then
-    AC_MSG_ERROR([Could not find NSS.  Either install it or configure using --disable-nss.])
-  fi
-  NSS_LIBDIR=`$PKG_CONFIG --variable=libdir nss`
-  AC_SUBST(NSS_LIBDIR)
-  AC_CONFIG_FILES([nss.cfg])
-fi
-
 if test "x${ZERO_BUILD_TRUE}" = x || test "x${ADD_ZERO_BUILD_TRUE}" = x; then
   dnl Check for libffi headers and libraries.
   PKG_CHECK_MODULES(LIBFFI, libffi,[LIBFFI_FOUND=yes],[LIBFFI_FOUND=no])
diff -r 5a890a745e14 -r 08661c42a3ba patches/icedtea-nss-not-enabled-config.patch
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/patches/icedtea-nss-not-enabled-config.patch	Sat Apr 10 22:07:13 2010 +0200
@@ -0,0 +1,13 @@
+--- openjdk.orig/jdk/src/share/lib/security/java.security	2009-08-25 11:43:59.000000000 +0100
++++ openjdk/jdk/src/share/lib/security/java.security		2009-08-27 14:23:54.000000000 +0100
+@@ -51,6 +51,10 @@
+ security.provider.6=com.sun.security.sasl.Provider
+ security.provider.7=org.jcp.xml.dsig.internal.dom.XMLDSigRI
+ security.provider.8=sun.security.smartcardio.SunPCSC
++# the NSS security provider was not enabled for this build; it can be enabled
++# if NSS (libnss3) is available on the machine. The nss.cfg file may need
++# editing to reflect the location of the NSS installation.
++#security.provider.9=sun.security.pkcs11.SunPKCS11 ${java.home}/lib/security/nss.cfg
+ 
+ #
+ # Select the source of seed data for SecureRandom. By default an
diff -r 5a890a745e14 -r 08661c42a3ba patches/zero/6939845.patch
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/patches/zero/6939845.patch	Sat Apr 10 22:07:13 2010 +0200
@@ -0,0 +1,20 @@
+--- openjdk.old/hotspot/src/share/vm/interpreter/bytecodeInterpreter.cpp	Wed Mar 31 11:55:22 2010
++++ openjdk/hotspot/src/share/vm/interpreter/bytecodeInterpreter.cpp	Wed Mar 31 11:55:22 2010
+@@ -2328,6 +2328,17 @@
+       }
+ 
+       DEFAULT:
++#ifdef ZERO
++          // Some zero configurations use the C++ interpreter as a
++          // fallback interpreter and have support for platform
++          // specific fast bytecodes which aren't supported here, so
++          // redispatch to the equivalent non-fast bytecode when they
++          // are encountered.
++          if (Bytecodes::is_defined((Bytecodes::Code)opcode)) {
++              opcode = (jubyte)Bytecodes::java_code((Bytecodes::Code)opcode);
++              goto opcode_switch;
++          }
++#endif
+           fatal2("\t*** Unimplemented opcode: %d = %s\n",
+                  opcode, Bytecodes::name((Bytecodes::Code)opcode));
+           goto finish;
diff -r 5a890a745e14 -r 08661c42a3ba patches/zero/cppInterpreter-fast-bytecodes.patch
--- a/patches/zero/cppInterpreter-fast-bytecodes.patch	Thu Apr 08 17:00:19 2010 +0200
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,15 +0,0 @@
-Index: openjdk/hotspot/src/share/vm/interpreter/bytecodeInterpreter.cpp
-===================================================================
---- openjdk.orig/hotspot/src/share/vm/interpreter/bytecodeInterpreter.cpp	2010-03-19 10:35:14.000000000 +0100
-+++ openjdk/hotspot/src/share/vm/interpreter/bytecodeInterpreter.cpp	2010-03-19 10:39:01.000000000 +0100
-@@ -2328,6 +2328,10 @@
-       }
- 
-       DEFAULT:
-+         if (Bytecodes::is_defined((Bytecodes::Code)opcode)) {
-+           opcode = (jubyte)Bytecodes::java_code((Bytecodes::Code)opcode);
-+           goto opcode_switch;
-+         }
-           fatal2("\t*** Unimplemented opcode: %d = %s\n",
-                  opcode, Bytecodes::name((Bytecodes::Code)opcode));
-           goto finish;
diff -r 5a890a745e14 -r 08661c42a3ba plugin/icedteanp/IcedTeaJavaRequestProcessor.cc
--- a/plugin/icedteanp/IcedTeaJavaRequestProcessor.cc	Thu Apr 08 17:00:19 2010 +0200
+++ b/plugin/icedteanp/IcedTeaJavaRequestProcessor.cc	Sat Apr 10 22:07:13 2010 +0200
@@ -60,21 +60,21 @@ JavaRequestProcessor::newMessageOnBus(co
 {
 
 	// Anything we are waiting for _MUST_ have and instance id and reference #
-	std::vector<std::string>* message_parts = IcedTeaPluginUtilities::strSplit(message, " ");
+	std::vector<std::string*>* message_parts = IcedTeaPluginUtilities::strSplit(message, " ");
 
-	IcedTeaPluginUtilities::printStringVector("JavaRequest::newMessageOnBus:", message_parts);
+	IcedTeaPluginUtilities::printStringPtrVector("JavaRequest::newMessageOnBus:", message_parts);
 
-	if (message_parts->at(0) == "context" && message_parts->at(2) == "reference")
-		if (atoi(message_parts->at(1).c_str()) == this->instance && atoi(message_parts->at(3).c_str()) == this->reference)
+	if (*(message_parts->at(0)) == "context" && *(message_parts->at(2)) == "reference")
+		if (atoi(message_parts->at(1)->c_str()) == this->instance && atoi(message_parts->at(3)->c_str()) == this->reference)
 		{
 			// Gather the results
 
 			// Let's get errors out of the way first
-			if (message_parts->at(4).find("Error") == 0)
+			if (!message_parts->at(4)->find("Error"))
 			{
 				for (int i=5; i < message_parts->size(); i++)
 				{
-					result->error_msg->append(message_parts->at(i));
+					result->error_msg->append(*(message_parts->at(i)));
 					result->error_msg->append(" ");
 				}
 
@@ -83,78 +83,78 @@ JavaRequestProcessor::newMessageOnBus(co
 				result->error_occurred = true;
 				result_ready = true;
 			}
-			else if (message_parts->at(4) == "GetStringUTFChars" ||
-			         message_parts->at(4) == "GetToStringValue")
+			else if (!message_parts->at(4)->find("GetStringUTFChars") ||
+			         !message_parts->at(4)->find("GetToStringValue"))
 			{
 				// first item is length, and it is radix 10
-				int length = strtol(message_parts->at(5).c_str(), NULL, 10);
+				int length = strtol(message_parts->at(5)->c_str(), NULL, 10);
 
 				IcedTeaPluginUtilities::getUTF8String(length, 6 /* start at */, message_parts, result->return_string);
 				result_ready = true;
 			}
-			else if (message_parts->at(4) == "GetStringChars") // GetStringChars (UTF-16LE/UCS-2)
+			else if (!message_parts->at(4)->find("GetStringChars")) // GetStringChars (UTF-16LE/UCS-2)
 			{
 				// first item is length, and it is radix 10
-				int length = strtol(message_parts->at(5).c_str(), NULL, 10);
+				int length = strtol(message_parts->at(5)->c_str(), NULL, 10);
 
 				IcedTeaPluginUtilities::getUTF16LEString(length, 6 /* start at */, message_parts, result->return_wstring);
 				result_ready = true;
-			} else if ((message_parts->at(4) == "FindClass") ||
-			        (message_parts->at(4) == "GetClassName") ||
-			        (message_parts->at(4) == "GetClassID") ||
-			        (message_parts->at(4) == "GetMethodID") ||
-			        (message_parts->at(4) == "GetStaticMethodID") ||
-			        (message_parts->at(4) == "GetObjectClass") ||
-                    (message_parts->at(4) == "NewObject") ||
-                    (message_parts->at(4) == "NewStringUTF") ||
-                    (message_parts->at(4) == "HasPackage") ||
-                    (message_parts->at(4) == "HasMethod") ||
-                    (message_parts->at(4) == "HasField") ||
-                    (message_parts->at(4) == "GetStaticFieldID") ||
-                    (message_parts->at(4) == "GetFieldID") ||
-                    (message_parts->at(4) == "GetJavaObject") ||
-                    (message_parts->at(4) == "IsInstanceOf") ||
-                    (message_parts->at(4) == "NewArray"))
+			} else if (!message_parts->at(4)->find("FindClass") ||
+			           !message_parts->at(4)->find("GetClassName") ||
+			           !message_parts->at(4)->find("GetClassID") ||
+			           !message_parts->at(4)->find("GetMethodID") ||
+			           !message_parts->at(4)->find("GetStaticMethodID") ||
+			           !message_parts->at(4)->find("GetObjectClass") ||
+			           !message_parts->at(4)->find("NewObject") ||
+			           !message_parts->at(4)->find("NewStringUTF") ||
+			           !message_parts->at(4)->find("HasPackage") ||
+			           !message_parts->at(4)->find("HasMethod") ||
+			           !message_parts->at(4)->find("HasField") ||
+			           !message_parts->at(4)->find("GetStaticFieldID") ||
+			           !message_parts->at(4)->find("GetFieldID") ||
+			           !message_parts->at(4)->find("GetJavaObject") ||
+			           !message_parts->at(4)->find("IsInstanceOf") ||
+			           !message_parts->at(4)->find("NewArray"))
 			{
-				result->return_identifier = atoi(message_parts->at(5).c_str());
-				result->return_string->append(message_parts->at(5)); // store it as a string as well, for easy access
+				result->return_identifier = atoi(message_parts->at(5)->c_str());
+				result->return_string->append(*(message_parts->at(5))); // store it as a string as well, for easy access
 				result_ready = true;
-			}  else if ((message_parts->at(4) == "DeleteLocalRef") ||
-		                (message_parts->at(4) == "NewGlobalRef"))
+			}  else if (!message_parts->at(4)->find("DeleteLocalRef") ||
+			            !message_parts->at(4)->find("NewGlobalRef"))
 			{
 			    result_ready = true; // nothing else to do
-			} else if ((message_parts->at(4) == "CallMethod") ||
-					   (message_parts->at(4) == "CallStaticMethod") ||
-					   (message_parts->at(4) == "GetField") ||
-					   (message_parts->at(4) == "GetStaticField") ||
-					   (message_parts->at(4) == "GetValue") ||
-	                   (message_parts->at(4) == "GetObjectArrayElement"))
+			} else if (!message_parts->at(4)->find("CallMethod") ||
+			           !message_parts->at(4)->find("CallStaticMethod") ||
+			           !message_parts->at(4)->find("GetField") ||
+			           !message_parts->at(4)->find("GetStaticField") ||
+			           !message_parts->at(4)->find("GetValue") ||
+			           !message_parts->at(4)->find("GetObjectArrayElement"))
 			{
 
-			    if (message_parts->at(5) == "literalreturn")
+			    if (!message_parts->at(5)->find("literalreturn"))
                 {
 			        // literal returns don't have a corresponding jni id
 			        result->return_identifier = 0;
-			        result->return_string->append(message_parts->at(5));
+			        result->return_string->append(*(message_parts->at(5)));
 			        result->return_string->append(" ");
-			        result->return_string->append(message_parts->at(6));
+			        result->return_string->append(*(message_parts->at(6)));
 
                 } else
 			    {
                     // Else it is a complex object
 
-			        result->return_identifier = atoi(message_parts->at(5).c_str());
-			        result->return_string->append(message_parts->at(5)); // store it as a string as well, for easy access
+			        result->return_identifier = atoi(message_parts->at(5)->c_str());
+			        result->return_string->append(*(message_parts->at(5))); // store it as a string as well, for easy access
 			    }
 
 				result_ready = true;
-			} else if ((message_parts->at(4) == "GetArrayLength"))
+			} else if (!message_parts->at(4)->find("GetArrayLength"))
             {
 			    result->return_identifier = 0; // length is not an "identifier"
-			    result->return_string->append(message_parts->at(5));
+			    result->return_string->append(*(message_parts->at(5)));
 			    result_ready = true;
-            } else if ((message_parts->at(4) == "SetField") ||
-                       (message_parts->at(4) == "SetObjectArrayElement"))
+            } else if (!message_parts->at(4)->find("SetField") ||
+                       !message_parts->at(4)->find("SetObjectArrayElement"))
             {
 
                 // nothing to do
@@ -163,13 +163,12 @@ JavaRequestProcessor::newMessageOnBus(co
                 result_ready = true;
             }
 
-			delete message_parts;
+            IcedTeaPluginUtilities::freeStringPtrVector(message_parts);
 			return true;
 		}
 
-	delete message_parts;
+    IcedTeaPluginUtilities::freeStringPtrVector(message_parts);
 	return false;
-
 }
 
 /**
diff -r 5a890a745e14 -r 08661c42a3ba plugin/icedteanp/IcedTeaNPPlugin.cc
--- a/plugin/icedteanp/IcedTeaNPPlugin.cc	Thu Apr 08 17:00:19 2010 +0200
+++ b/plugin/icedteanp/IcedTeaNPPlugin.cc	Sat Apr 10 22:07:13 2010 +0200
@@ -131,7 +131,7 @@ exception statement from your version. *
 #define PLUGIN_FILE_EXTS "class,jar,zip"
 #define PLUGIN_MIME_COUNT 1
 
-#define FAILURE_MESSAGE "gcjwebplugin error: Failed to run %s." \
+#define FAILURE_MESSAGE "icedteanp plugin error: Failed to run %s." \
   "  For more detail rerun \"firefox -g\" in a terminal window."
 
 #if MOZILLA_VERSION_COLLAPSED < 1090100
@@ -194,8 +194,8 @@ typedef union
 #endif
 
 // Static instance helper functions.
-// Have the browser allocate a new GCJPluginData structure.
-static void plugin_data_new (GCJPluginData** data);
+// Have the browser allocate a new ITNPPluginData structure.
+static void plugin_data_new (ITNPPluginData** data);
 // Retrieve the current document's documentbase.
 static gchar* plugin_get_documentbase (NPP instance);
 // Notify the user that the appletviewer is not installed correctly.
@@ -208,11 +208,11 @@ static gboolean plugin_out_pipe_callback
 static gboolean plugin_out_pipe_callback (GIOChannel* source,
                                           GIOCondition condition,
                                           gpointer plugin_data);
-static NPError plugin_start_appletviewer (GCJPluginData* data);
+static NPError plugin_start_appletviewer (ITNPPluginData* data);
 static gchar* plugin_create_applet_tag (int16_t argc, char* argn[],
                                         char* argv[]);
 static void plugin_stop_appletviewer ();
 // Uninitialize GCJPluginData structure
 static void plugin_data_destroy (NPP instance);
 
 NPError get_cookie_info(const char* siteAddr, char** cookieString, uint32_t* len);
@@ -238,8 +238,8 @@ int plugin_debug = getenv ("ICEDTEAPLUGI
 
 pthread_cond_t cond_message_available = PTHREAD_COND_INITIALIZER;
 
 // Functions prefixed by GCJ_ are instance functions.  They are called
 // by the browser and operate on instances of GCJPluginData.
 // Functions prefixed by plugin_ are static helper functions.
 // Functions prefixed by NP_ are factory functions.  They are called
 // by the browser and provide functionality needed to create plugin
@@ -247,22 +247,22 @@ pthread_cond_t cond_message_available = 
 
 // INSTANCE FUNCTIONS
 
 // Creates a new gcjwebplugin instance.  This function creates a
 // GCJPluginData* and stores it in instance->pdata.  The following
 // GCJPluginData fiels are initialized: instance_string, in_pipe_name,
 // in_from_appletviewer, in_watch_source, out_pipe_name,
 // out_to_appletviewer, out_watch_source, appletviewer_mutex, owner,
 // appletviewer_alive.  In addition two pipe files are created.  All
 // of those fields must be properly destroyed, and the pipes deleted,
 // by GCJ_Destroy.  If an error occurs during initialization then this
 // function will free anything that's been allocated so far, set
 // instance->pdata to NULL and return an error code.
 NPError
-GCJ_New (NPMIMEType pluginType, NPP instance, uint16_t mode,
+ITNP_New (NPMIMEType pluginType, NPP instance, uint16_t mode,
          int16_t argc, char* argn[], char* argv[],
          NPSavedData* saved)
 {
-  PLUGIN_DEBUG_0ARG("GCJ_New\n");
+  PLUGIN_DEBUG_0ARG("ITNP_New\n");
 
   static NPObject *window_ptr;
   NPIdentifier identifier;
@@ -280,7 +280,7 @@ GCJ_New (NPMIMEType pluginType, NPP inst
 
 
   NPError np_error = NPERR_NO_ERROR;
-  GCJPluginData* data = NULL;
+  ITNPPluginData* data = NULL;
 
   gchar* documentbase = NULL;
   gchar* read_message = NULL;
@@ -401,7 +401,7 @@ GCJ_New (NPMIMEType pluginType, NPP inst
   g_hash_table_insert(id_to_instance_map, GINT_TO_POINTER(instance_counter), instance);
   instance_counter++;
 
-  PLUGIN_DEBUG_0ARG ("GCJ_New return\n");
+  PLUGIN_DEBUG_0ARG ("ITNP_New return\n");
 
@@ -208,11 +208,11 @@ static gboolean plugin_out_pipe_callback
                                         char* argv[]);
 static void plugin_stop_appletviewer ();
-// Uninitialize GCJPluginData structure
+// Uninitialize ITNPPluginData structure
 static void plugin_data_destroy (NPP instance);
 
@@ -238,8 +238,8 @@ int plugin_debug = getenv ("ICEDTEAPLUGI
 pthread_cond_t cond_message_available = PTHREAD_COND_INITIALIZER;
 
-// Functions prefixed by GCJ_ are instance functions.  They are called
-// by the browser and operate on instances of GCJPluginData.
+// Functions prefixed by ITNP_ are instance functions.  They are called
+// by the browser and operate on instances of ITNPPluginData.
 // Functions prefixed by plugin_ are static helper functions.
 // Functions prefixed by NP_ are factory functions.  They are called
@@ -247,22 +247,22 @@ pthread_cond_t cond_message_available = 
 // INSTANCE FUNCTIONS
 
-// Creates a new gcjwebplugin instance.  This function creates a
-// GCJPluginData* and stores it in instance->pdata.  The following
-// GCJPluginData fiels are initialized: instance_string, in_pipe_name,
+// Creates a new icedtea np plugin instance.  This function creates a
+// ITNPPluginData* and stores it in instance->pdata.  The following
+// ITNPPluginData fiels are initialized: instance_string, in_pipe_name,
 // in_from_appletviewer, in_watch_source, out_pipe_name,
 // out_to_appletviewer, out_watch_source, appletviewer_mutex, owner,
@@ -247,22 +247,22 @@ pthread_cond_t cond_message_available = 
 // appletviewer_alive.  In addition two pipe files are created.  All
 // of those fields must be properly destroyed, and the pipes deleted,
-// by GCJ_Destroy.  If an error occurs during initialization then this
+// by ITNP_Destroy.  If an error occurs during initialization then this
 // function will free anything that's been allocated so far, set
 // instance->pdata to NULL and return an error code.



More information about the distro-pkg-dev mailing list